@@ -571,8 +571,8 @@ setMethod(
   lastOneDone <- TRUE
 
   while (length(parse(text = deparse(parseTxt))[[1]]) != 1) {
-    if(length(parseTxt)==2) {
-      stop("Please pass an object directly, or use get(x, envir=envName) or eval(x, envir=envName). ",
+    if (length(parseTxt) == 2) {
+      stop("Please pass an object directly, or use get(x, envir = envName) or eval(x, envir = envName). ",
            "Plot can not yet accept functions or complex objects internally.")
     }
 
@@ -609,7 +609,7 @@ setMethod(
         }
       )
     }
-    if(as.character(parseTxt[[1]])=="[[") {
+    if (as.character(parseTxt[[1]]) == "[[") {
       parseTxt[[3]] <- tryCatch(
         eval(parseTxt[[3]], envir = e),
         error = function(x) {
@@ -656,10 +656,10 @@ setMethod(
       parseTxt[[3]] <- as.name(parseTxt[[3]])
     }
     if (is.numeric(parseTxt[[3]])) {
-      if (!is.null(names(eval(parseTxt[[2]], envir=e)))) {
-        parseTxt[[3]] <- names(eval(parseTxt[[2]], envir=e))[parseTxt[[3]]]
-        if(is.na(parseTxt[[3]])){
-          stop("Please pass an object directly, or use get(x, envir=envName) or eval(x, envir=envName). ",
+      if (!is.null(names(eval(parseTxt[[2]], envir = e)))) {
+        parseTxt[[3]] <- names(eval(parseTxt[[2]], envir = e))[parseTxt[[3]]]
+        if (is.na(parseTxt[[3]])) {
+          stop("Please pass an object directly, or use get(x, envir = envName) or eval(x, envir = envName). ",
                "Plot can not yet accept functions or complex objects internally.")
         }
       }
@@ -683,11 +683,11 @@ setMethod(
   }
 
 #   envs <- append(.GlobalEnv, sys.frames())[c(TRUE, sapply(sys.frames(), function(x)
-#     exists(deparse(parseTxt), envir=x, inherits=FALSE)))] %>%
+#     exists(deparse(parseTxt), envir = x, inherits = FALSE)))] %>%
 #     .[[length(.)]]
   envs <- append(.GlobalEnv, sys.frames()) %>%
     .[c(TRUE, sapply(sys.frames(), function(x) {
-      exists(deparse(parseTxt), envir=x, inherits=FALSE)
+      exists(deparse(parseTxt), envir = x, inherits = FALSE)
       }))] %>%
     .[[length(.)]]
 
@@ -701,24 +701,24 @@ setMethod(
     envs <- callEnv
   }
 
-#browser()
-
   if (!inGlobal) {
     if (!exists(paste0("dev", dev.cur()), envir = .spadesEnv)) {
       .spadesEnv[[paste0("dev", dev.cur())]] <- new.env(parent = emptyenv())
     }
-    #if(is(get(deparse(rev(elems)[[1]]), envir=envs), "simList")) { # If it is a simList
-    #  changeObjEnv(deparse(elems[[1]]),
-    #               fromEnv=envir(get(deparse(rev(elems)[[1]]), envir=envs)),
-    #               toEnv=.spadesEnv[[paste0("dev", dev.cur())]])
-    #} else { # If it is NOT a simList.
+
+    if (is(get(deparse(rev(elems)[[1]]), envir = envs), "simList")) { # If it is a simList
+      changeObjEnv(deparse(elems[[1]]),
+                   fromEnv = envir(get(deparse(rev(elems)[[1]]), envir = envs)),
+                   toEnv = .spadesEnv[[paste0("dev", dev.cur())]])
+    } else { # If it is NOT a simList.
       changeObjEnv(paste(sapply(rev(elems), deparse), collapse = "$"),
-                 fromEnv=envs, toEnv=.spadesEnv[[paste0("dev", dev.cur())]])
-    #}
+                 fromEnv = envs, toEnv = .spadesEnv[[paste0("dev", dev.cur())]])
+    }
   }
 
-  if(sapply(elems[[1]], is.numeric)) {
-    return(list(objs = paste0(paste0(sapply(rev(elems), deparse), collapse="[["),"]]"),
+  if (sapply(elems[[1]], is.numeric)) {
+    return(list(objs = paste0(paste0(sapply(rev(elems), deparse),
+                                     collapse = "[["), "]]"),
                 envs = envs))
   }
   return(list(objs = paste(sapply(rev(elems), deparse), collapse = "$"),
@@ -761,10 +761,10 @@ setMethod(
   eminus1 <- sys.frame(frameCalledFrom - 1)
 
   if (nchar(argName) == 0) {
-    callNamedArgs <- as.character(substitute(list(...), env=e))[-1]
+    callNamedArgs <- as.character(substitute(list(...), env = e))[-1]
   } else {
-  #  callNamedArgs <- as.character(substitute(parse(text=argName)))[-1]
-    callNamedArgs <- as.character(substitute(parse(text=sim), env=e))[-1]
+  #  callNamedArgs <- as.character(substitute(parse(text = argName)))[-1]
+    callNamedArgs <- as.character(substitute(parse(text = sim), env = e))[-1]
   }
   objs <- lapply(callNamedArgs, .parseArgs, e, eminus1)
   return(objs)
