@@ -40,28 +40,24 @@ setMethod(
   ".makeSpadesPlot",
   signature = c(plotObjects = "list", plotArgs = "list"),
   definition = function(plotObjects, plotArgs, ...) {
-
-
     isSpatialObjects <- sapply(plotObjects, function(x) {
       is(x, "spatialObjects")
     })
 
     env <- list(...)$env
     suppliedNames <- names(plotObjects)
-    if (is.null(suppliedNames)){
+    if (is.null(suppliedNames)) {
       objs <- .objectNames()[whichSpadesPlottables]
     } else {
-      objs <- lapply(suppliedNames, function(x) list(objs=x, envs=env))
+      objs <- lapply(suppliedNames, function(x) list(objs = x, envs = env))
     }
 
-
     names(plotObjects) <- sapply(objs,function(x)
       x$objs)
 
     if (!is.null(suppliedNames)) {
       if (all(sapply(suppliedNames, nchar) > 0)) {
         names(plotObjects)[!is.na(suppliedNames)] <- suppliedNames
-
       }
     }
     numLayers <- pmax(1, sapply(plotObjects, nlayers))
@@ -505,7 +501,16 @@ setMethod(
       pretty(range(minv, maxv))
     } else {
       if (!is.null(legendText)) {
-        unique(round(pretty(range(minv, maxv), n=length(legendText))))
+        if(NCOL(legendText)>1){ # means it was a factor
+          if(identical(legendText$ID,1:NROW(legendText))) {
+            unique(round(pretty(range(minv, maxv), n=length(levels(legendText[,2])))))
+          } else {
+            legendText$contigValue <- 1:NROW(legendText)
+            legendText$contigValue
+          }
+        } else {
+          unique(round(pretty(range(minv, maxv), n=length(legendText))))
+        }
       } else {
         unique(round(pretty(range(minv, maxv))))
       }
@@ -530,25 +535,40 @@ setMethod(
           name = "raster"
         ),
         if (legend) {
+
+          if(NCOL(legendText)>1) {
+            # for factors
+            colForLegend <- col[rev(legendText$ID+1)]
+          } else {
+            colForLegend <- col[(maxcol):mincol]
+          }
           rasterGrob(
-            as.raster(col[(maxcol):mincol]),
+            as.raster(colForLegend),
             x = 1.04, y = 0.5,
             height = 0.5, width = 0.03,
             interpolate = FALSE,
             name = "legend"
           )
+
         },
         if (legend) {
           txt <- if (is.null(legendText)) {
             pr
           } else {
             legendIndex <- pr - min(pr) + 1
-            legendText[legendIndex]
+            if(NCOL(legendText)>1){ # for factor legends
+              legendText[legendIndex,2]
+            } else {
+              legendText[legendIndex]
+            }
           }
           textGrob(
             txt,
             x = 1.08,
             y = if (maxv >= 3) {
+              if(NCOL(legendText)>1){ # factors
+                maxv <- NROW(legendText)
+              }
               ((pr - minv) / ((maxv + 1) - minv)) / 2 + 0.25 + 1 /
                 (diff(range(minv, maxv)) + 1) / 4
             } else {
@@ -642,7 +662,7 @@ setMethod(
 
 #     xyOrd <- do.call(rbind, lapply(xyOrd.l, function(i) { do.call(rbind, i) }))
 
-    if (nrow(xyOrd) > 1e3) {
+    if (NROW(xyOrd) > 1e3) {
       # thin if greater than 1000 pts
       if (speedup>0.1) {
         if (requireNamespace("fastshp", quietly = TRUE)) {
@@ -650,7 +670,7 @@ setMethod(
             thin = fastshp::thin(xyOrd[, 1], xyOrd[, 2],
                                  tolerance = speedupScale * speedup)
           )
-          #thinned[, groups:= rep(1:nrow(idLength), idLength$V1)]
+          #thinned[, groups:= rep(1:NROW(idLength), idLength$V1)]
           #idLength <- thinned[, sum(thin),by = groups]
           xyOrd <- xyOrd[thinned$thin, ]
         } else {
@@ -752,7 +772,7 @@ setMethod(
 
     xyOrd <- do.call(rbind, lapply(xyOrd.l, function(i) { do.call(rbind, i) }))
 
-    if (nrow(xyOrd) > 1e3) {
+    if (NROW(xyOrd) > 1e3) {
       # thin if fewer than 1000 pts
       if (speedup>0.1) {
 
@@ -761,7 +781,7 @@ setMethod(
             thin = fastshp::thin(xyOrd[, 1], xyOrd[, 2],
                                  tolerance = speedupScale * speedup)
           )
-          thinned[, groups:= rep(1:nrow(idLength), idLength$V1)]
+          thinned[, groups:= rep(1:NROW(idLength), idLength$V1)]
           idLength <- thinned[, sum(thin),by = groups]
           xyOrd <- xyOrd[thinned$thin, ]
         } else {
@@ -822,7 +842,7 @@ setMethod(
     idLength <- unlist(lapply(xy, length)) / 2
     xy <- do.call(rbind,xy)
 
-    if (nrow(xy) > 1e3) {
+    if (NROW(xy) > 1e3) {
       # thin if fewer than 1000 pts
       if (speedup>0.1) {
 
@@ -1256,7 +1276,7 @@ setMethod(
 #' @export
 #' @importFrom gridBase gridFIG
 #' @importFrom ggplot2 ggplot
-#' @importFrom raster crop
+#' @importFrom raster crop is.factor
 #' @importFrom grid upViewport pushViewport seekViewport grid.text
 #' @importFrom grid grid.rect grid.xaxis grid.yaxis current.parent gpar
 #' @importFrom grDevices dev.cur dev.size
@@ -1308,6 +1328,19 @@ setMethod(
 #' caribou <- cbind(x = stats::runif (1e2, -50, 50), y = stats::runif (1e2, -50, 50)) %>%
 #'   SpatialPoints(coords = .)
 #'
+#' # use factor raster to give legends as character strings
+#' ras <- raster(matrix(sample(1:4, size=12, replace=TRUE),
+#'    ncol=4, nrow=3))
+#' # needs to have a data.frame with ID as first column - see ?raster::ratify
+#' levels(ras) <- data.frame(ID=1:4, Name=paste0("Level",1:4))
+#' Plot(ras, new=T)
+#'
+#' # Arbitrary values for factors
+#' levels <- c(1,2,7)
+#' ras <- raster(matrix(sample(levels, size=12, replace=TRUE),
+#'    ncol=4, nrow=3))
+#' levels(ras) <- data.frame(ID=levels, Name=sample(LETTERS,3))
+#' Plot(ras, new=T)
 #' \notrun{
 #' dev(2)
 #' }
@@ -1622,6 +1655,7 @@ setMethod(
               )
             }
 
+
             if (is(grobToPlot, "Raster")) {
               # Rasters may be zoomed into and subsampled and have unique legend
               pR <- .prepareRaster(grobToPlot, sGrob@plotArgs$zoomExtent,
@@ -1712,13 +1746,21 @@ setMethod(
               }
             } else {
               # Extract legend text if the raster is a factored raster
-              if (is.factor(grobToPlot) & is.null(legendText)) {
-                sGrob@plotArgs$legendTxt <- levels(grobToPlot)[[1]][,2]
+              if(is.null(legendText)) {
+                if(is.null(sGrob@plotArgs$legendTxt)) {
+                  if (raster::is.factor(grobToPlot)) {
+                    sGrob@plotArgs$legendTxt <- grobToPlot@data@attributes[[1]]#[,2]
+                  }
+                }
               } else {
                 sGrob@plotArgs$legendTxt <- legendText
+                updated$curr@spadesGrobList[[subPlots]][[spadesGrobCounter]]@plotArgs$legendTxt <-
+                  legendText
+
               }
-              sGrob@plotArgs$legendTxt <- if (!isBaseSubPlot | !isReplot) {
-                NULL
+
+              if (!isBaseSubPlot ) {#| isReplot) {
+                sGrob@plotArgs$legendTxt <- NULL
               }
 
               plotGrobCall <- list(
@@ -1781,8 +1823,8 @@ setMethod(
     sim <- list(...)[[1]]
     plotList <- ls(sim@.envir, all.names = TRUE)
     plotObjects = mget(plotList[sapply(plotList, function(x)
-      is(get(x, envir=envir(sim)), ".spadesPlottables"))], envir(sim)) %>%
-      append(., list(env=envir(sim)))
+      is(get(x, envir = envir(sim)), ".spadesPlottables"))], envir(sim)) %>%
+      append(., list(env = envir(sim)))
     do.call(Plot, plotObjects)
 })
 
