@@ -1,6 +1,12 @@
 test_that("adj.R results not identical to adjacent", {
-  library(sp); on.exit(detach("package:sp"))  # for adjacent function
-  library(raster); on.exit(detach("package:raster"))  # for adjacent function
+  library(sp) # for adjacent function
+  library(raster) # for adjacent function
+
+  on.exit({
+    detach("package:raster")
+    detach("package:sp")
+  })
+
   a <- raster::raster(raster::extent(0, 1e3, 0, 1e3), res = 1)
 
   # smaller sample (should use matrix)
